@@ -1,6 +1,10 @@
 import logging
-from typing import Any, Dict
 from collections import defaultdict
+from typing import Any, Dict
+
+import click
+
+from .click_common import command, format_output
 from .device import Device, DeviceException
 
 _LOGGER = logging.getLogger(__name__)
@@ -62,14 +66,25 @@ class CeilStatus:
         return self.data["ac"] == 1
 
     def __repr__(self) -> str:
-        s = "<CeilStatus power=%s, brightness=%s, " \
-            "color_temperature=%s, scene=%s, delay_off_countdown=%s, " \
-            "smart_night_light=%s, automatic_color_temperature=%s>" % \
-            (self.power, self.brightness,
-             self.color_temperature, self.scene, self.delay_off_countdown,
-             self.smart_night_light, self.automatic_color_temperature)
+        s = "<CeilStatus power=%s, " \
+            "brightness=%s, " \
+            "color_temperature=%s, " \
+            "scene=%s, " \
+            "delay_off_countdown=%s, " \
+            "smart_night_light=%s, " \
+            "automatic_color_temperature=%s>" % \
+            (self.power,
+             self.brightness,
+             self.color_temperature,
+             self.scene,
+             self.delay_off_countdown,
+             self.smart_night_light,
+             self.automatic_color_temperature)
         return s
 
+    def __json__(self):
+        return self.data
+
 
 class Ceil(Device):
     """Main class representing Xiaomi Philips LED Ceiling Lamp."""
@@ -77,6 +92,18 @@ class Ceil(Device):
     # TODO: - Auto On/Off Not Supported
     #       - Adjust Scenes with Wall Switch Not Supported
 
+    @command(
+        default_output=format_output(
+            "",
+            "Power: {result.power}\n"
+            "Brightness: {result.brightness}\n"
+            "Color temperature: {result.color_temperature}\n"
+            "Scene: {result.scene}\n"
+            "Delayed turn off: {result.delay_off_countdown}\n"
+            "Smart night light: {result.smart_night_light}\n"
+            "Automatic color temperature: {result.automatic_color_temperature}\n"
+        )
+    )
     def status(self) -> CeilStatus:
         """Retrieve properties."""
         properties = ['power', 'bright', 'cct', 'snm', 'dv', 'bl', 'ac', ]
@@ -95,14 +122,24 @@ class Ceil(Device):
 
         return CeilStatus(defaultdict(lambda: None, zip(properties, values)))
 
+    @command(
+        default_output=format_output("Powering on"),
+    )
     def on(self):
         """Power on."""
         return self.send("set_power", ["on"])
 
+    @command(
+        default_output=format_output("Powering on"),
+    )
     def off(self):
         """Power off."""
         return self.send("set_power", ["off"])
 
+    @command(
+        click.argument("level", type=int),
+        default_output=format_output("Setting brightness to {level}")
+    )
     def set_brightness(self, level: int):
         """Set brightness level."""
         if level < 1 or level > 100:
@@ -110,6 +147,10 @@ class Ceil(Device):
 
         return self.send("set_bright", [level])
 
+    @command(
+        click.argument("level", type=int),
+        default_output=format_output("Setting color temperature to {level}")
+    )
     def set_color_temperature(self, level: int):
         """Set Correlated Color Temperature."""
         if level < 1 or level > 100:
@@ -117,6 +158,12 @@ class Ceil(Device):
 
         return self.send("set_cct", [level])
 
+    @command(
+        click.argument("brightness", type=int),
+        click.argument("cct", type=int),
+        default_output=format_output(
+            "Setting brightness to {brightness} and color temperature to {cct}")
+    )
     def set_brightness_and_color_temperature(self, brightness: int, cct: int):
         """Set brightness level and the correlated color temperature."""
         if brightness < 1 or brightness > 100:
@@ -127,6 +174,10 @@ class Ceil(Device):
 
         return self.send("set_bricct", [brightness, cct])
 
+    @command(
+        click.argument("seconds", type=int),
+        default_output=format_output("Setting delayed turn off to {seconds} seconds")
+    )
     def delay_off(self, seconds: int):
         """Turn off delay in seconds."""
 
@@ -136,6 +187,10 @@ class Ceil(Device):
 
         return self.send("delay_off", [seconds])
 
+    @command(
+        click.argument("number", type=int),
+        default_output=format_output("Setting fixed scene to {number}")
+    )
     def set_scene(self, number: int):
         """Set a fixed scene. 4 fixed scenes are available (1-4)"""
         if number < 1 or number > 4:
@@ -143,18 +198,30 @@ class Ceil(Device):
 
         return self.send("apply_fixed_scene", [number])
 
+    @command(
+        default_output=format_output("Turning on smart night light"),
+    )
     def smart_night_light_on(self):
         """Smart Night Light On."""
         return self.send("enable_bl", [1])
 
+    @command(
+        default_output=format_output("Turning off smart night light"),
+    )
     def smart_night_light_off(self):
         """Smart Night Light off."""
         return self.send("enable_bl", [0])
 
+    @command(
+        default_output=format_output("Turning on automatic color temperature"),
+    )
     def automatic_color_temperature_on(self):
         """Automatic color temperature on."""
         return self.send("enable_ac", [1])
 
+    @command(
+        default_output=format_output("Turning off automatic color temperature"),
+    )
     def automatic_color_temperature_off(self):
         """Automatic color temperature off."""
         return self.send("enable_ac", [0])
